==> winvnsrc_0_99_8.zip: RCS/wvdlg.h <==
head	1.40;
access;
symbols
	V0-99-8:1.40
	V0-99-7:1.38
	V0-99-6:1.36
	V0-99-5:1.35
	V0-99-4:1.35
	V0-99-2:1.32
	V0-99-1:1.32
	V0-93-14:1.32
	V0-93-13:1.32
	V0-93-12:1.32
	V0-93-11:1.32
	V0-93-10:1.32
	V0-93-9:1.32
	V0-93-8:1.32
	V0-93-7:1.32
	V0-93-5:1.31
	V80:1.5
	V76d:1.1;
locks; strict;
comment	@ * @;


1.40
date	96.08.31.06.51.46;	author dumoulin;	state Exp;
branches;
next	1.39;

1.39
date	96.08.13.03.40.02;	author brydon;	state Exp;
branches;
next	1.38;

1.38
date	95.11.09.00.09.37;	author dumoulin;	state Exp;
branches;
next	1.37;

1.37
date	95.11.07.21.42.01;	author dumoulin;	state Exp;
branches;
next	1.36;

1.36
date	95.08.16.22.31.42;	author dumoulin;	state Exp;
branches;
next	1.35;

1.35
date	95.05.19.23.21.45;	author dumoulin;	state Exp;
branches;
next	1.34;

1.34
date	95.04.17.23.26.16;	author dumoulin;	state Exp;
branches;
next	1.33;

1.33
date	95.04.12.20.47.36;	author dumoulin;	state Exp;
branches;
next	1.32;

1.32
date	94.11.21.21.20.46;	author jcooper;	state Exp;
branches;
next	1.31;

1.31
date	94.11.10.01.50.23;	author rushing;	state Exp;
branches;
next	;


desc
@winvn version 0.76 placed into RCS
@


1.40
log
@add support for selecting between XOVER and XHDR in COMM dialog box
@
text
@/*
 * $Id: wvdlg.h 1.39 1996/08/13 03:40:02 brydon Exp $
 */
#ifndef __WVDLG__
#define __WVDLG__
#include "version.h"

#define ID_OK                           IDOK
#define ID_CANCEL                       IDCANCEL
#define ID_OK_SAVE                      11
#define OK                              108
#define IDD_OK_SAVE                     109

#define IDD_COM1                        300
#define IDD_COM2                        301
#define IDD_7EVEN                       302
#define IDD_8NONE                       303
#define IDD_SPEED                       304
#define ID_COMMTCP                      305
#define ID_COMMSERIAL                   306

#define ID_CONFIG_NNTP_SERVER           310
#define ID_CONFIG_NNTP_PORT             311
#define ID_STATUSALWAYSONTOP            312
#define ID_CONFIG_NAME                  320
#define ID_CONFIG_EMAIL                 321
#define ID_CONFIG_ORG                   322
#define ID_CONFIG_SHOWUNSUB             324
#define ID_CONFIG_SHOWREAD              325
#define ID_CONFIG_CONFIRM_BATCH         326
#define ID_CONFIG_CONFIRM_EXIT          327
#define ID_CONFIG_CONFIRM_REPLY_TO      328
#define ID_CONFIG_CONNECT_AT_START      329
#define ID_DOLIST_BASE                  330
#define ID_DOLIST_YES                   331
#define ID_DOLIST_ASK                   332
#define ID_DOLIST_NO                    333
#define ID_CONFIG_THREADS               334
#define ID_BROWSE                       335
#define ID_CONFIG_THREADS_FULL_SUBJECT  336		/* SMR 940301 */
#define ID_CONFIG_MULTI_SELECT          337		/* jlg 28-apr-94 */
#define ID_CONFIG_SHOWUNREADONLY        338		/* wrp 05-JUL-94 */
#define ID_CONFIRM_DISCONNECT           339
#define ID_CONFIG_NEW_WND_GROUP         340
#define ID_CONFIG_NEW_WND_ARTICLE       341
#define ID_CONFIG_APPEND                342
#define ID_CONFIG_SAVE_NEWSRC_ON_CLOSE  343     /* JD 4/1/95 */
#define ID_CONFIG_DO_LIST               344
#define ID_TRIM_HEADERS                 345
#define ID_SCROLL_PAST_HEADERS          346
#define ID_QUOTES_IN_ITALICS            347
#define ID_WRAP_INCOMING_TEXT           348
#define ID_WRAP_INCOMING_TEXT_LIMIT     349
#define ID_THREAD_DEPTH_INDICATOR       350
#define ID_CONFIG_TIMEZONE              351		/* JD 5/17/95 */
#define ID_CONFIG_ARTICLE_FIXED_FONT    352
#define ID_CONFIG_CROSSPOST	            353     /* JD 5/12/95 */
#define ID_CONFIG_CROSSPOST_UNSUB       354		/* JD 5/12/95 */
#define ID_CONFIG_URL_HTTP              355     /* JD 7/23/95 */
#define ID_CONFIG_URL_FTP               356     /* JD 7/23/95 */
#define ID_CONFIG_URL_GOPHER            357     /* JD 7/23/95 */
#define ID_CONFIG_URL_WAIS              358     /* JD 7/23/95 */
#define ID_CONFIG_MAPI_PREFIX           359     /* JD 9/30/95 */
#define ID_ENABLE_KILLFILE              360	    /* JD 3/02/96 */

#define IDD_FILENAME                    501
#define IDD_APPEND                      502
#define IDD_KEEP_HEADER_VISIBLE         503
#define IDD_VERSION_LISTBOX             508		/* JD 8/3/94 */
#define IDD_VERSION_NUMBER              509		/* JD 8/3/94 */
#define IDD_SEARCH_STRING               510
#define IDD_SUBJECT_STRING              511
#define ID_CONFIG_FULLNAMEFROM          512
#define IDD_SUBJECT_PROMPT              513
#define ID_CONFIG_SMTP_SERVER           514
#define IDD_MAIL_SELECT_NONE            515
#define IDD_MAIL_SELECT_MAPI            516
#define IDD_MAIL_SELECT_SMTP            517
#define IDD_MAIL_SELECT_AUTO            518
#define IDD_REPLY_TO                    519
#define IDD_CC_BY_MAIL                  520
#define IDD_CC_ADDRESS                  521

#define ID_CONFIG_AUTH_USERNAME         522
#define ID_CONFIG_AUTH_PASSWORD         523
#define IDD_SAVEPASSWORD                524
#define IDD_DEMANDLOGON                 525
#define IDM_SHOW_VERSION                526

#define IDD_MAILLOG                     530
#define IDD_POSTLOG						531
#define IDD_MAILNAME                    532
#define IDD_POSTNAME                    533
#define ID_BROWSEPOST                   534
#define ID_BROWSEMAIL                   535
#define IDD_NEWS_SELECT_BASE            536		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_XOVER           537		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_XHDR            538		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_AUTO            539		/* JD 8/14/96 */


#define IDD_CODING_TYPE                 550		/* en/decode JSC 9/12/93 */
#define IDD_ATTACH_NOW		        551
#define IDD_ATTACH_NEXT		        552
#define IDD_CONTENT_TYPE	        553
#define IDD_ARTICLE_SPLIT_LENGTH        554
#define IDD_CUSTOM_TABLE                555
#define IDD_SUBJECT_TEMPLATE	        556
#define IDD_REVIEW                      557
#define IDD_NO_REVIEW                   558
#define IDD_MIME_BOUNDARY               559
#define IDD_GENERATE_MIME               560
#define IDD_MIME_USAGE_SUGGESTIONS      561
#define IDD_MAKE_DEFAULT_ENCODING       562
#define IDD_MAKE_DEFAULT_CONTENT        563

#define IDD_DECODE_PATH                 900
#define IDD_DUMB_DECODE                 901
#define IDD_VERBOSE_STATUS              902
#define IDD_ENABLE_SIG                  903
#define IDD_EXECUTE_DECODED             904
#define IDD_SMART_FILER                 905
#define IDD_MINIMIZE_CODING_STATUS      906
#define IDD_INCLUDE_OPEN_ARTS           907

#define IDC_HEADER_EDIT                 912		// shimomai

#define IDD_SAVE_NEWSRC                 570
#define IDD_SAVE_CONFIG                 571

#define IDD_DELETE                      575
#define IDD_ADD                         576
#define IDD_MAIL_DEST                   577
#define IDD_MAIL_LIST                   578

#define IDD_PRINT                       600
#define IDD_PRINTDEVICE                 601		/* JD 930205 */
#define IDD_PRINTPORT                   602		/* JD 930205 */
#define IDD_PRINTTITLE                  603		/* JD 930205 */
#define IDD_PRINTSTATUS			604		/* JD 940623 */
#define IDD_PRINTSUBJECT		605		/* JD 940623 */

#define ID_100_ARTS                     650
#define ID_250_ARTS                     651
#define ID_500_ARTS                     652
#define ID_THRESHOLD_ALL                654
#define IDD_ART_THRESHOLD               655
#define IDD_ARTS_TO_GRAB                656
#define ID_THRESHOLD_UNREAD             657
#define IDD_MIN_TO_READ                 658

#define IDD_HIERARCHY_LISTBOX           700
#define IDD_SUBSCRIBED_GROUP_LISTBOX    701
#define IDD_UNSUBSCRIBED_GROUP_LISTBOX  702

#define IDD_FOLLOWUP_TEMPLATE           730
#define IDD_REPLY_TEMPLATE              731
#define IDD_SHOW_REPLYTO_HDR            732
#define IDD_SHOW_ORG_HDR                733
#define IDD_SHOW_KEYWORDS_HDR           734
#define IDD_SHOW_SUMMARY_HDR            735
#define IDD_SHOW_DISTRIBUTION_HDR       736
#define IDD_WORD_WRAP                   737
#define IDD_SHOW_FROM_HDR               738
#define IDD_PREFILL_CC                  739
#define IDD_SHOW_FOLLOWUPTO_HDR         740

#define IDD_EXT_MAP_LIST                750		/* for smart filer jsc 9/9/94 */
#define IDD_SOURCE_EXT                  751
#define IDD_DOS_EXT                     752
#define IDD_NAME_SHORTEN                753
#define IDD_AVOID_DUPES                 754
#define IDD_ENABLE_CONVERSION           755
#define IDD_MAX_NAME_LEN                756
#define IDD_MAX_EXT_LEN                 757

#define ID_DRIVELIST                    800
#define ID_DIRECTORYLIST                801
#define ID_TEMPLIST                     802

// Article Action dialog
#define IDM_VIEW_ACTION                 830
#define IDC_AA_RADIO_GLOBAL             831
#define IDC_AA_RADIO_GROUP              832
#define IDC_AA_NEW                      840
#define IDC_AA_DELETE                   841
#define IDC_AA_EDIT_PREV                845
#define IDC_AA_EDIT_NEXT                846
#define IDC_AA_MOVE_PREV                847
#define IDC_AA_MOVE_NEXT                848
#define IDC_AA_HEADER                   850
#define IDC_AA_HDRFILTER                851
//#define IDC_AA_NUM_LINES              852
#define IDC_AA_LINESTEXT                853
#define IDC_AA_TEXT                     854
#define IDC_AA_ACTION                   855
#endif
@


1.39
log
@add enable_killfile and IDC_HEADER_EDIT defs
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.38 1995/11/09 00:09:37 dumoulin Exp $
d91 1
a91 1
#define IDD_POSTLOG		        531
d96 4
d101 1
@


1.38
log
@Patches to support Harvey Brydons variable MIME boundaries code
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.37 1995/11/07 21:42:01 dumoulin Exp dumoulin $
d64 1
d121 2
@


1.37
log
@Added support for user to configure MAPI prefix string
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.36 1995/08/16 22:31:42 dumoulin Exp $
d172 17
@


1.36
log
@added defines to support clicking on URLs
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.35 1995/05/19 23:21:45 dumoulin Exp $
d63 1
@


1.35
log
@added defines to support timezone setting and crossposted
articles dialog boxes.
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.34 1995/04/17 23:26:16 dumoulin Exp $
d59 4
@


1.34
log
@Allow Followup-to header to be displayed in Posting window
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.33 1995/04/12 20:47:36 dumoulin Exp dumoulin $
d55 1
a55 1

d57 2
a62 1

@


1.33
log
@Make saving Newsrc when closing group an option
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.32 1994/11/21 21:20:46 jcooper Exp $
d152 1
@


1.32
log
@93.7 update
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.31 1994/11/10 01:50:23 rushing Exp $
d47 1
@


1.31
log
@restart
@
text
@d4 2
a5 1

d164 1
@

==> winvnsrc_0_99_9.zip: RCS/wvdlg.h <==
head	1.43;
access;
symbols
	V0-99-8:1.40
	V0-99-7:1.38
	V0-99-6:1.36
	V0-99-5:1.35
	V0-99-4:1.35
	V0-99-2:1.32
	V0-99-1:1.32
	V0-93-14:1.32
	V0-93-13:1.32
	V0-93-12:1.32
	V0-93-11:1.32
	V0-93-10:1.32
	V0-93-9:1.32
	V0-93-8:1.32
	V0-93-7:1.32
	V0-93-5:1.31
	V80:1.5
	V76d:1.1;
locks; strict;
comment	@ * @;


1.43
date	97.03.07.01.57.14;	author dumoulin;	state Exp;
branches;
next	1.42;

1.42
date	97.02.08.11.07.37;	author dumoulin;	state Exp;
branches;
next	1.41;

1.41
date	97.02.06.21.26.15;	author dumoulin;	state Exp;
branches;
next	1.40;

1.40
date	96.08.31.06.51.46;	author dumoulin;	state Exp;
branches;
next	1.39;

1.39
date	96.08.13.03.40.02;	author brydon;	state Exp;
branches;
next	1.38;

1.38
date	95.11.09.00.09.37;	author dumoulin;	state Exp;
branches;
next	1.37;

1.37
date	95.11.07.21.42.01;	author dumoulin;	state Exp;
branches;
next	1.36;

1.36
date	95.08.16.22.31.42;	author dumoulin;	state Exp;
branches;
next	1.35;

1.35
date	95.05.19.23.21.45;	author dumoulin;	state Exp;
branches;
next	1.34;

1.34
date	95.04.17.23.26.16;	author dumoulin;	state Exp;
branches;
next	1.33;

1.33
date	95.04.12.20.47.36;	author dumoulin;	state Exp;
branches;
next	1.32;

1.32
date	94.11.21.21.20.46;	author jcooper;	state Exp;
branches;
next	1.31;

1.31
date	94.11.10.01.50.23;	author rushing;	state Exp;
branches;
next	;


desc
@winvn version 0.76 placed into RCS
@


1.43
log
@added support to DDE for mosaic and user setable server ID string
@
text
@/*
 * $Id: wvdlg.h 1.42 1997/02/08 11:07:37 dumoulin Exp $
 */
#ifndef __WVDLG__
#define __WVDLG__
#include "version.h"

#define ID_OK                           IDOK
#define ID_CANCEL                       IDCANCEL
#define ID_OK_SAVE                      11
#define OK                              108
#define IDD_OK_SAVE                     109

#define IDD_COM1                        300
#define IDD_COM2                        301
#define IDD_7EVEN                       302
#define IDD_8NONE                       303
#define IDD_SPEED                       304
#define ID_COMMTCP                      305
#define ID_COMMSERIAL                   306

#define ID_CONFIG_NNTP_SERVER           310
#define ID_CONFIG_NNTP_PORT             311
#define ID_STATUSALWAYSONTOP            312
#define ID_CONFIG_NAME                  320
#define ID_CONFIG_EMAIL                 321
#define ID_CONFIG_ORG                   322
#define ID_CONFIG_SHOWUNSUB             324
#define ID_CONFIG_SHOWREAD              325
#define ID_CONFIG_CONFIRM_BATCH         326
#define ID_CONFIG_CONFIRM_EXIT          327
#define ID_CONFIG_CONFIRM_REPLY_TO      328
#define ID_CONFIG_CONNECT_AT_START      329
#define ID_DOLIST_BASE                  330
#define ID_DOLIST_YES                   331
#define ID_DOLIST_ASK                   332
#define ID_DOLIST_NO                    333
#define ID_CONFIG_THREADS               334
#define ID_BROWSE                       335
#define ID_CONFIG_THREADS_FULL_SUBJECT  336		/* SMR 940301 */
#define ID_CONFIG_MULTI_SELECT          337		/* jlg 28-apr-94 */
#define ID_CONFIG_SHOWUNREADONLY        338		/* wrp 05-JUL-94 */
#define ID_CONFIRM_DISCONNECT           339
#define ID_CONFIG_NEW_WND_GROUP         340
#define ID_CONFIG_NEW_WND_ARTICLE       341
#define ID_CONFIG_APPEND                342
#define ID_CONFIG_SAVE_NEWSRC_ON_CLOSE  343     /* JD 4/1/95 */
#define ID_CONFIG_DO_LIST               344
#define ID_TRIM_HEADERS                 345
#define ID_SCROLL_PAST_HEADERS          346
#define ID_QUOTES_IN_ITALICS            347
#define ID_WRAP_INCOMING_TEXT           348
#define ID_WRAP_INCOMING_TEXT_LIMIT     349
#define ID_THREAD_DEPTH_INDICATOR       350
#define ID_CONFIG_TIMEZONE              351		/* JD 5/17/95 */
#define ID_CONFIG_ARTICLE_FIXED_FONT    352
#define ID_CONFIG_CROSSPOST	            353     /* JD 5/12/95 */
#define ID_CONFIG_CROSSPOST_UNSUB       354		/* JD 5/12/95 */
#define ID_CONFIG_URL_HTTP              355     /* JD 7/23/95 */
#define ID_CONFIG_URL_FTP               356     /* JD 7/23/95 */
#define ID_CONFIG_URL_GOPHER            357     /* JD 7/23/95 */
#define ID_CONFIG_URL_WAIS              358     /* JD 7/23/95 */
#define ID_CONFIG_MAPI_PREFIX           359     /* JD 9/30/95 */
#define ID_ENABLE_KILLFILE              360	    /* JD 3/02/96 */
#define ID_CONFIG_SORT_GROUPLIST        361     /* JD 1/03/96 */

#define IDD_FILENAME                    501
#define IDD_APPEND                      502
#define IDD_KEEP_HEADER_VISIBLE         503
#define IDD_VERSION_LISTBOX             508		/* JD 8/3/94 */
#define IDD_VERSION_NUMBER              509		/* JD 8/3/94 */
#define IDD_SEARCH_STRING               510
#define IDD_SUBJECT_STRING              511
#define ID_CONFIG_FULLNAMEFROM          512
#define IDD_SUBJECT_PROMPT              513
#define ID_CONFIG_SMTP_SERVER           514
#define IDD_MAIL_SELECT_NONE            515
#define IDD_MAIL_SELECT_MAPI            516
#define IDD_MAIL_SELECT_SMTP            517
#define IDD_MAIL_SELECT_AUTO            518
#define IDD_REPLY_TO                    519
#define IDD_CC_BY_MAIL                  520
#define IDD_CC_ADDRESS                  521

#define ID_CONFIG_AUTH_USERNAME         522
#define ID_CONFIG_AUTH_PASSWORD         523
#define IDD_SAVEPASSWORD                524
#define IDD_DEMANDLOGON                 525
#define IDM_SHOW_VERSION                526

#define IDD_MAILLOG                     530
#define IDD_POSTLOG						531
#define IDD_MAILNAME                    532
#define IDD_POSTNAME                    533
#define ID_BROWSEPOST                   534
#define ID_BROWSEMAIL                   535
#define IDD_NEWS_SELECT_BASE            536		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_XOVER           537		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_XHDR            538		/* JD 8/14/96 */
#define IDD_NEWS_SELECT_AUTO            539		/* JD 8/14/96 */


#define IDD_CODING_TYPE                 550		/* en/decode JSC 9/12/93 */
#define IDD_ATTACH_NOW		        551
#define IDD_ATTACH_NEXT		        552
#define IDD_CONTENT_TYPE	        553
#define IDD_ARTICLE_SPLIT_LENGTH        554
#define IDD_CUSTOM_TABLE                555
#define IDD_SUBJECT_TEMPLATE	        556
#define IDD_REVIEW                      557
#define IDD_NO_REVIEW                   558
#define IDD_MIME_BOUNDARY               559
#define IDD_GENERATE_MIME               560
#define IDD_MIME_USAGE_SUGGESTIONS      561
#define IDD_MAKE_DEFAULT_ENCODING       562
#define IDD_MAKE_DEFAULT_CONTENT        563


#define IDD_SAVE_NEWSRC                 570
#define IDD_SAVE_CONFIG                 571

#define IDD_DELETE                      575
#define IDD_ADD                         576
#define IDD_MAIL_DEST                   577
#define IDD_MAIL_LIST                   578

#define IDD_PRINT                       600
#define IDD_PRINTDEVICE                 601		/* JD 930205 */
#define IDD_PRINTPORT                   602		/* JD 930205 */
#define IDD_PRINTTITLE                  603		/* JD 930205 */
#define IDD_PRINTSTATUS			604		/* JD 940623 */
#define IDD_PRINTSUBJECT		605		/* JD 940623 */

#define ID_100_ARTS                     650
#define ID_250_ARTS                     651
#define ID_500_ARTS                     652
#define ID_THRESHOLD_ALL                654
#define IDD_ART_THRESHOLD               655
#define IDD_ARTS_TO_GRAB                656
#define ID_THRESHOLD_UNREAD             657
#define IDD_MIN_TO_READ                 658

#define IDD_HIERARCHY_LISTBOX           700
#define IDD_SUBSCRIBED_GROUP_LISTBOX    701
#define IDD_UNSUBSCRIBED_GROUP_LISTBOX  702

#define IDD_FOLLOWUP_TEMPLATE           730
#define IDD_REPLY_TEMPLATE              731
#define IDD_SHOW_REPLYTO_HDR            732
#define IDD_SHOW_ORG_HDR                733
#define IDD_SHOW_KEYWORDS_HDR           734
#define IDD_SHOW_SUMMARY_HDR            735
#define IDD_SHOW_DISTRIBUTION_HDR       736
#define IDD_WORD_WRAP                   737
#define IDD_SHOW_FROM_HDR               738
#define IDD_PREFILL_CC                  739
#define IDD_SHOW_FOLLOWUPTO_HDR         740

#define IDD_EXT_MAP_LIST                750		/* for smart filer jsc 9/9/94 */
#define IDD_SOURCE_EXT                  751
#define IDD_DOS_EXT                     752
#define IDD_NAME_SHORTEN                753
#define IDD_AVOID_DUPES                 754
#define IDD_ENABLE_CONVERSION           755
#define IDD_MAX_NAME_LEN                756
#define IDD_MAX_EXT_LEN                 757

#define ID_DRIVELIST                    800
#define ID_DIRECTORYLIST                801
#define ID_TEMPLIST                     802

// Article Action dialog
#define IDM_VIEW_ACTION                 830
#define IDC_AA_RADIO_GLOBAL             831
#define IDC_AA_RADIO_GROUP              832
#define IDC_AA_NEW                      840
#define IDC_AA_DELETE                   841
#define IDC_AA_EDIT_PREV                845
#define IDC_AA_EDIT_NEXT                846
#define IDC_AA_MOVE_PREV                847
#define IDC_AA_MOVE_NEXT                848
#define IDC_AA_HEADER                   850
#define IDC_AA_HDRFILTER                851
//#define IDC_AA_NUM_LINES              852
#define IDC_AA_LINESTEXT                853
#define IDC_AA_TEXT                     854
#define IDC_AA_ACTION                   855

#define IDD_DECODE_PATH                 900
#define IDD_DUMB_DECODE                 901
#define IDD_VERBOSE_STATUS              902
#define IDD_ENABLE_SIG                  903
#define IDD_EXECUTE_DECODED             904
#define IDD_SMART_FILER                 905
#define IDD_MINIMIZE_CODING_STATUS      906
#define IDD_INCLUDE_OPEN_ARTS           907

#define IDC_HEADER_EDIT                 912		// shimomai

#define IDC_CONFIG_URL_DDE              1036	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_DDE_STATIC       1037	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_DDE_RADIO        1038	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_DDE_RADIO1       1039	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_DDE_RADIO2       1040	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_DDE_RADIO3       1041    /* dumoulin 3/4/97  */
#define IDC_CONFIG_URL_DDE_RADIO4       1042    /* dumoulin 3/4/97  */

#define IDC_CONFIG_URL_BUTTON1          1046	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON2          1047	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON3          1048	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON4          1049	/* shimomai 5/08/96 */

#define IDC_CONFIG_URL_DDE_SERVER_ID    1052    /* dumoulin 3/4/97 */
#define IDC_CONFIG_URL_DDE_ID_STRING    1053    /* dumoulin 3/4/97 */


#endif
@


1.42
log
@changes for bitmap range support
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.41 1997/02/06 21:26:15 dumoulin Exp root $
d205 2
a206 4
#define IDC_CONFIG_URL_BUTTON1          1041	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON2          1042	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON3          1043	/* shimomai 5/08/96 */
#define IDC_CONFIG_URL_BUTTON4          1044	/* shimomai 5/08/96 */
d208 9
@


1.41
log
@mods to support changes from ints to longs
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.40 1996/08/31 06:51:46 dumoulin Exp $
a117 10
#define IDD_DECODE_PATH                 900
#define IDD_DUMB_DECODE                 901
#define IDD_VERBOSE_STATUS              902
#define IDD_ENABLE_SIG                  903
#define IDD_EXECUTE_DECODED             904
#define IDD_SMART_FILER                 905
#define IDD_MINIMIZE_CODING_STATUS      906
#define IDD_INCLUDE_OPEN_ARTS           907

#define IDC_HEADER_EDIT                 912		// shimomai
d188 22
@


1.40
log
@add support for selecting between XOVER and XHDR in COMM dialog box
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.39 1996/08/13 03:40:02 brydon Exp $
d65 1
@


1.39
log
@add enable_killfile and IDC_HEADER_EDIT defs
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.38 1995/11/09 00:09:37 dumoulin Exp $
d91 1
a91 1
#define IDD_POSTLOG		        531
d96 4
d101 1
@


1.38
log
@Patches to support Harvey Brydons variable MIME boundaries code
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.37 1995/11/07 21:42:01 dumoulin Exp dumoulin $
d64 1
d121 2
@


1.37
log
@Added support for user to configure MAPI prefix string
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.36 1995/08/16 22:31:42 dumoulin Exp $
d172 17
@


1.36
log
@added defines to support clicking on URLs
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.35 1995/05/19 23:21:45 dumoulin Exp $
d63 1
@


1.35
log
@added defines to support timezone setting and crossposted
articles dialog boxes.
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.34 1995/04/17 23:26:16 dumoulin Exp $
d59 4
@


1.34
log
@Allow Followup-to header to be displayed in Posting window
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.33 1995/04/12 20:47:36 dumoulin Exp dumoulin $
d55 1
a55 1

d57 2
a62 1

@


1.33
log
@Make saving Newsrc when closing group an option
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.32 1994/11/21 21:20:46 jcooper Exp $
d152 1
@


1.32
log
@93.7 update
@
text
@d2 1
a2 1
 * $Id: wvdlg.h 1.31 1994/11/10 01:50:23 rushing Exp $
d47 1
@


1.31
log
@restart
@
text
@d4 2
a5 1

d164 1
@
